

# zetup.py



[![](http://www.gnu.org/graphics/lgplv3-88x31.png)](
  http://www.gnu.org/licenses/lgpl.html)
[![](https://pypip.in/version/zetup/badge.svg)](
  https://pypi.python.org/pypi/zetup)
[![](https://pypip.in/py_versions/zetup/badge.svg)](
  https://pypi.python.org/pypi/zetup)
[![](https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master)](
  https://travis-ci.org/userzimmermann/zetup.py)



## Zimmermann's [Python](http://python.org) package setup



* https://bitbucket.org/userzimmermann/zetup.py
* https://github.com/userzimmermann/zetup.py
* https://www.openhub.net/p/python-zetup

